/*
*  
*  $Id: commandsynchronizewithgui.h 4078 2011-08-16 10:19:52Z tovar $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma once
//#define _GINKGO_TRACE
#include <api/api.h>
#include <api/globals.h>
#include <api/icomando.h>
#include <api/ientorno.h>
#include <api/icontroladoreventos.h>
#include <api/imodelointegracion.h>

namespace GADAPI {
	class EXTAPI ISynchronizedData {
	public:
		ISynchronizedData(){}
		virtual ~ISynchronizedData(){}
	};

	class EXTAPI ISynchronizedWithGUI
	{
	public:
		virtual void ExecuteSynchronized(GADAPI::ISynchronizedData* pData) = 0;
	};

	class EXTAPI CommandSynchronizeWithGUI : public GNC::GCS::IComando {
	public:
		CommandSynchronizeWithGUI(ISynchronizedWithGUI* pParam, ISynchronizedData * pData = NULL, bool clearData = false);
		virtual ~CommandSynchronizeWithGUI();

	 protected:
		virtual void Execute();
		virtual void Update();

	protected:
		ISynchronizedWithGUI* m_pListener;
		ISynchronizedData * m_pData;
		bool m_clearData;
	};
}
